# <img src='./logo.svg' card_color="#FF8600" width="50" style="vertical-align:bottom" style="vertical-align:bottom">Launcher

Browse the web by voice

## Description

This skill is used to browse the web.

## Examples

- "Browse to neon.ai"
- "Navigate to google.com"

## Contact Support

Use the [link](https://neongecko.com/ContactUs) or [submit an issue on GitHub](https://help.github.com/en/articles/creating-an-issue)

## Credits
[NeonGeckoCom](https://github.com/NeonGeckoCom)
[NeonDaniel](https://github.com/NeonDaniel)
[reginaneon](https://github.com/reginaneon)

## Category
**Productivity**
Daily

## Tags
#NeonGecko Original
#NeonAI
#browser
#desktop
#web